diff --git a/src/test/perl/TestLib.pm b/src/test/perl/TestLib.pm
index 905d0d1..25ab1f2 100644
--- a/src/test/perl/TestLib.pm
+++ b/src/test/perl/TestLib.pm
@@ -112,6 +112,22 @@ BEGIN
 
 	# Must be set early
 	$windows_os = $Config{osname} eq 'MSWin32' || $Config{osname} eq 'msys';
+	if ($windows_os)
+	{
+		require Win32::API;
+		Win32::API->import;
+
+		require Win32API::File;
+		Win32API::File->import(qw(
+			:Func
+			:Misc
+			:FILE_
+			:FILE_FLAG_
+			:FILE_SHARE_
+			:FILE_ATTRIBUTE_
+			:GENERIC_
+		));
+	}
 }
 
 =pod
@@ -394,10 +410,25 @@ sub slurp_file
 {
 	my ($filename) = @_;
 	local $/;
-	open(my $in, '<', $filename)
-	  or die "could not read \"$filename\": $!";
-	my $contents = <$in>;
-	close $in;
+	my $contents;
+	if (!$windows_os)
+	{
+		open(my $in, '<', $filename)
+		  or die "could not read \"$filename\": $!";
+		$contents = <$in>;
+		close $in;
+	}
+	else
+	{
+		my $fHandle = CreateFile($filename, GENERIC_READ(),
+		  FILE_SHARE_DELETE()|FILE_SHARE_READ()|FILE_SHARE_WRITE(), [], OPEN_EXISTING(), 0, [])
+		  or die "could not read \"$filename\": $^E";
+		OsFHandleOpen(my $fh = IO::Handle->new(), $fHandle, 'r')
+		  or die "OsFHandleOpen: $^E\n";
+		$contents = <$fh>;
+		CloseHandle($fHandle)
+		  or die "CloseHandle: $^E\n";
+	}
 	$contents =~ s/\r//g if $Config{osname} eq 'msys';
 	return $contents;
 }
